#!/usr/bin/python3
#
# File:    ./setup.py
# Author:  Jiří Kučera <sanczes AT gmail.com>
# Date:    2022-06-24 14:03:43 +0200
# Project: vutils-python: Python language tools
#
# SPDX-License-Identifier: MIT
#
"""Setup for vutils-python."""

from setuptools import setup

setup()
